@if "%DEBUG%" == "" @echo off
@rem ##########################################################################
@rem
@rem  client startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

set DIRNAME=%~dp0
if "%DIRNAME%" == "" set DIRNAME=.
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Add default JVM options here. You can also use JAVA_OPTS and CLIENT_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if "%ERRORLEVEL%" == "0" goto init

echo.
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto init

echo.
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:init
@rem Get command-line arguments, handling Windows variants

if not "%OS%" == "Windows_NT" goto win9xME_args

:win9xME_args
@rem Slurp the command line arguments.
set CMD_LINE_ARGS=
set _SKIP=2

:win9xME_args_slurp
if "x%~1" == "x" goto execute

set CMD_LINE_ARGS=%*

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\client-1.5.6.8617-SNAPSHOT.jar;%APP_HOME%\lib\lombok-1.16.6.jar;%APP_HOME%\lib\utility-0.0.27-SNAPSHOT.jar;%APP_HOME%\lib\queue-0.0.37-SNAPSHOT.jar;%APP_HOME%\lib\swagger-annotations-1.5.13.jar;%APP_HOME%\lib\commons-httpclient-3.1.jar;%APP_HOME%\lib\httpmime-4.5.2.jar;%APP_HOME%\lib\spring-core-4.3.5.RELEASE.jar;%APP_HOME%\lib\spring-web-4.3.5.RELEASE.jar;%APP_HOME%\lib\validation-api-1.0.0.GA.jar;%APP_HOME%\lib\protobuf-java-3.1.0.jar;%APP_HOME%\lib\slf4j-api-1.7.7.jar;%APP_HOME%\lib\jackson-dataformat-xml-2.8.5.jar;%APP_HOME%\lib\protobuf-java-format-1.4.jar;%APP_HOME%\lib\protostuff-core-1.5.2.jar;%APP_HOME%\lib\protostuff-runtime-1.5.2.jar;%APP_HOME%\lib\protostuff-api-1.5.2.jar;%APP_HOME%\lib\protostuff-runtime-1.0.12.jar;%APP_HOME%\lib\commons-lang3-3.2.jar;%APP_HOME%\lib\flying-saucer-pdf-9.0.8.jar;%APP_HOME%\lib\velocity-1.7.jar;%APP_HOME%\lib\velocity-tools-2.0.jar;%APP_HOME%\lib\commons-io-2.5.jar;%APP_HOME%\lib\joda-time-2.9.4.jar;%APP_HOME%\lib\aws-java-sdk-sns-1.11.75.jar;%APP_HOME%\lib\spring-jms-4.3.5.RELEASE.jar;%APP_HOME%\lib\amazon-sqs-java-messaging-lib-1.0.1.jar;%APP_HOME%\lib\json-20160810.jar;%APP_HOME%\lib\commons-logging-1.2.jar;%APP_HOME%\lib\spring-aop-4.3.5.RELEASE.jar;%APP_HOME%\lib\spring-beans-4.3.5.RELEASE.jar;%APP_HOME%\lib\spring-context-4.3.5.RELEASE.jar;%APP_HOME%\lib\aws-java-sdk-sqs-1.11.75.jar;%APP_HOME%\lib\aws-java-sdk-core-1.11.75.jar;%APP_HOME%\lib\jmespath-java-1.11.75.jar;%APP_HOME%\lib\spring-messaging-4.3.5.RELEASE.jar;%APP_HOME%\lib\spring-tx-4.3.5.RELEASE.jar;%APP_HOME%\lib\geronimo-jms_1.1_spec-1.1.1.jar;%APP_HOME%\lib\spring-expression-4.3.5.RELEASE.jar;%APP_HOME%\lib\httpclient-4.5.2.jar;%APP_HOME%\lib\ion-java-1.0.1.jar;%APP_HOME%\lib\jackson-dataformat-cbor-2.6.6.jar;%APP_HOME%\lib\httpcore-4.4.4.jar;%APP_HOME%\lib\commons-codec-1.9.jar;%APP_HOME%\lib\common-0.2.38-SNAPSHOT.jar;%APP_HOME%\lib\jackson-module-jaxb-annotations-2.8.5.jar;%APP_HOME%\lib\stax2-api-3.1.4.jar;%APP_HOME%\lib\woodstox-core-5.0.3.jar;%APP_HOME%\lib\protostuff-collectionschema-1.5.2.jar;%APP_HOME%\lib\protostuff-api-1.0.12.jar;%APP_HOME%\lib\protostuff-collectionschema-1.0.12.jar;%APP_HOME%\lib\itext-2.1.7.jar;%APP_HOME%\lib\flying-saucer-core-9.0.8.jar;%APP_HOME%\lib\commons-collections-3.2.1.jar;%APP_HOME%\lib\commons-lang-2.4.jar;%APP_HOME%\lib\commons-beanutils-1.7.0.jar;%APP_HOME%\lib\commons-digester-1.8.jar;%APP_HOME%\lib\commons-chain-1.1.jar;%APP_HOME%\lib\commons-validator-1.3.1.jar;%APP_HOME%\lib\dom4j-1.1.jar;%APP_HOME%\lib\oro-2.0.8.jar;%APP_HOME%\lib\sslext-1.2-0.jar;%APP_HOME%\lib\struts-core-1.3.8.jar;%APP_HOME%\lib\struts-taglib-1.3.8.jar;%APP_HOME%\lib\struts-tiles-1.3.8.jar;%APP_HOME%\lib\bcmail-jdk14-138.jar;%APP_HOME%\lib\bcprov-jdk14-138.jar;%APP_HOME%\lib\antlr-2.7.2.jar;%APP_HOME%\lib\bctsp-jdk14-1.38.jar;%APP_HOME%\lib\bcprov-jdk14-1.38.jar;%APP_HOME%\lib\bcmail-jdk14-1.38.jar;%APP_HOME%\lib\jackson-core-2.8.5.jar;%APP_HOME%\lib\jackson-annotations-2.8.5.jar;%APP_HOME%\lib\jackson-databind-2.8.5.jar

@rem Execute client
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %CLIENT_OPTS%  -classpath "%CLASSPATH%" /api/src/main/java/org/ewaybill/bridge/api/Application.java %CMD_LINE_ARGS%

:end
@rem End local scope for the variables with windows NT shell
if "%ERRORLEVEL%"=="0" goto mainEnd

:fail
rem Set variable CLIENT_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
if  not "" == "%CLIENT_EXIT_CONSOLE%" exit 1
exit /b 1

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
